summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/basic/basrdll.hxx5
-rw-r--r--include/canvas/rendering/bitmap.hxx4
-rw-r--r--include/comphelper/asyncnotification.hxx8
-rw-r--r--include/comphelper/scoped_disposing_ptr.hxx17
-rw-r--r--include/comphelper/storagehelper.hxx6
-rw-r--r--include/comphelper/syntaxhighlight.hxx8
-rw-r--r--include/dbaccess/dbaundomanager.hxx4
-rw-r--r--include/editeng/Trie.hxx6
-rw-r--r--include/filter/msfilter/msdffimp.hxx7
-rw-r--r--include/framework/documentundoguard.hxx8
-rw-r--r--include/framework/undomanagerhelper.hxx4
-rw-r--r--include/o3tl/cow_wrapper.hxx4
-rw-r--r--include/oox/core/filterbase.hxx4
-rw-r--r--include/oox/core/xmlfilterbase.hxx2
-rw-r--r--include/oox/crypto/DocumentDecryption.hxx4
-rw-r--r--include/sax/fshelper.hxx6
-rw-r--r--include/sfx2/dispatch.hxx3
-rw-r--r--include/sfx2/itemconnect.hxx7
-rw-r--r--include/sfx2/taskpane.hxx5
-rw-r--r--include/svl/asiancfg.hxx4
-rw-r--r--include/svl/undo.hxx7
-rw-r--r--include/svtools/DocumentInfoPreview.hxx3
-rw-r--r--include/svtools/popupwindowcontroller.hxx3
-rw-r--r--include/svtools/ruler.hxx6
-rw-r--r--include/svtools/valueset.hxx6
-rw-r--r--include/svx/dialcontrol.hxx8
-rw-r--r--include/svx/framelinkarray.hxx10
-rw-r--r--include/svx/ruler.hxx22
-rw-r--r--include/svx/sidebar/Popup.hxx5
-rw-r--r--include/svx/svdomedia.hxx2
-rw-r--r--include/svx/svdpage.hxx11
-rw-r--r--include/svx/tbcontrl.hxx4
-rw-r--r--include/svx/zoomsliderctrl.hxx5
-rw-r--r--include/toolkit/awt/animatedimagespeer.hxx5
-rw-r--r--include/toolkit/controls/animatedimages.hxx9
-rw-r--r--include/toolkit/controls/unocontrols.hxx6
-rw-r--r--include/unotools/atom.hxx9
-rw-r--r--include/unotools/closeveto.hxx7
-rw-r--r--include/unotools/localedatawrapper.hxx16
-rw-r--r--include/unotools/sharedunocomponent.hxx19
-rw-r--r--include/unotools/useroptions.hxx7
-rw-r--r--include/vcl/builder.hxx6
-rw-r--r--include/vcl/button.hxx4
-rw-r--r--include/vcl/opengl/OpenGLContext.hxx7
-rw-r--r--include/vcl/openglwin.hxx4
-rw-r--r--include/vcl/outdev.hxx10
-rw-r--r--include/vcl/pdfwriter.hxx4
-rw-r--r--include/vcl/region.hxx9
-rw-r--r--include/vcl/svapp.hxx4
-rw-r--r--include/vcl/svgdata.hxx11
-rw-r--r--include/xmloff/txtimp.hxx4
-rw-r--r--include/xmloff/txtparae.hxx4
-rw-r--r--include/xmloff/xmlcnimp.hxx4
53 files changed, 154 insertions, 203 deletions
diff --git a/include/basic/basrdll.hxx b/include/basic/basrdll.hxx
index 274126d6c461..45ce39e2e3e1 100644
--- a/include/basic/basrdll.hxx
+++ b/include/basic/basrdll.hxx
@@ -20,9 +20,8 @@
#ifndef INCLUDED_BASIC_BASRDLL_HXX
#define INCLUDED_BASIC_BASRDLL_HXX
-#include <boost/scoped_ptr.hpp>
-
#include <basic/basicdllapi.h>
+#include <memory>
class ResMgr;
@@ -30,7 +29,7 @@ class BASIC_DLLPUBLIC BasicDLL
{
public:
struct Impl;
- ::boost::scoped_ptr<Impl> m_pImpl;
+ std::unique_ptr<Impl> m_xImpl;
public:
BasicDLL();
diff --git a/include/canvas/rendering/bitmap.hxx b/include/canvas/rendering/bitmap.hxx
index f68f74f34f91..9fc1070f243a 100644
--- a/include/canvas/rendering/bitmap.hxx
+++ b/include/canvas/rendering/bitmap.hxx
@@ -30,7 +30,7 @@
#include <canvas/rendering/isurfaceproxymanager.hxx>
#include <boost/shared_ptr.hpp>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
#include <vector>
namespace basegfx
@@ -303,7 +303,7 @@ namespace canvas
private:
friend class ImplBitmap;
- const ::boost::scoped_ptr< ImplBitmap > mpImpl;
+ const std::unique_ptr< ImplBitmap > mxImpl;
};
typedef ::boost::shared_ptr< Bitmap > BitmapSharedPtr;
diff --git a/include/comphelper/asyncnotification.hxx b/include/comphelper/asyncnotification.hxx
index 58cb17df6a44..01d589c8540e 100644
--- a/include/comphelper/asyncnotification.hxx
+++ b/include/comphelper/asyncnotification.hxx
@@ -22,19 +22,15 @@
#include <sal/config.h>
-#include <boost/scoped_ptr.hpp>
#include <comphelper/comphelperdllapi.h>
#include <rtl/ref.hxx>
#include <sal/types.h>
#include <salhelper/thread.hxx>
#include <salhelper/simplereferenceobject.hxx>
-
+#include <memory>
namespace comphelper
{
-
-
-
//= AnyEvent
/** the very basic instance to hold a description of an event
@@ -104,7 +100,7 @@ namespace comphelper
friend struct EventNotifierImpl;
private:
- boost::scoped_ptr< EventNotifierImpl > m_pImpl;
+ std::unique_ptr<EventNotifierImpl> m_xImpl;
SAL_DLLPRIVATE virtual ~AsyncEventNotifier();
diff --git a/include/comphelper/storagehelper.hxx b/include/comphelper/storagehelper.hxx
index 38c664fd49b3..ec551d7d70bc 100644
--- a/include/comphelper/storagehelper.hxx
+++ b/include/comphelper/storagehelper.hxx
@@ -19,13 +19,11 @@
#ifndef INCLUDED_COMPHELPER_STORAGEHELPER_HXX
#define INCLUDED_COMPHELPER_STORAGEHELPER_HXX
-#include <boost/scoped_ptr.hpp>
-
#include <com/sun/star/uno/Sequence.hxx>
#include <com/sun/star/uno/Reference.hxx>
#include <com/sun/star/embed/ElementModes.hpp>
#include <comphelper/comphelperdllapi.h>
-
+#include <memory>
#define PACKAGE_STORAGE_FORMAT_STRING "PackageFormat"
#define ZIP_STORAGE_FORMAT_STRING "ZipFormat"
@@ -58,7 +56,7 @@ class COMPHELPER_DLLPUBLIC LifecycleProxy
private:
class Impl;
public:
- ::boost::scoped_ptr<Impl> m_pBadness;
+ std::unique_ptr<Impl> m_xBadness;
LifecycleProxy();
~LifecycleProxy();
// commit the storages: necessary for writes to streams to take effect!
diff --git a/include/comphelper/syntaxhighlight.hxx b/include/comphelper/syntaxhighlight.hxx
index ef190bcf3b24..16d3c12e046d 100644
--- a/include/comphelper/syntaxhighlight.hxx
+++ b/include/comphelper/syntaxhighlight.hxx
@@ -19,10 +19,7 @@
#ifndef INCLUDED_COMPHELPER_SYNTAXHIGHLIGHT_HXX
#define INCLUDED_COMPHELPER_SYNTAXHIGHLIGHT_HXX
-#include <vector>
-
#include <boost/noncopyable.hpp>
-#include <boost/scoped_ptr.hpp>
#include <rtl/ustring.hxx>
#include <comphelper/comphelperdllapi.h>
@@ -31,6 +28,9 @@
#include <sys/resource.h>
#endif
+#include <vector>
+#include <memory>
+
// Token-Typen TT_...
enum TokenTypes
{
@@ -71,7 +71,7 @@ class COMPHELPER_DLLPUBLIC SyntaxHighlighter: private boost::noncopyable
class Tokenizer;
HighlighterLanguage eLanguage;
- boost::scoped_ptr<Tokenizer> m_tokenizer;
+ std::unique_ptr<Tokenizer> m_tokenizer;
public:
SyntaxHighlighter(HighlighterLanguage language);
diff --git a/include/dbaccess/dbaundomanager.hxx b/include/dbaccess/dbaundomanager.hxx
index c9bcef7ca5df..e52176fe0343 100644
--- a/include/dbaccess/dbaundomanager.hxx
+++ b/include/dbaccess/dbaundomanager.hxx
@@ -26,7 +26,7 @@
#include <cppuhelper/implbase1.hxx>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
class SfxUndoManager;
@@ -84,7 +84,7 @@ namespace dbaui
virtual void SAL_CALL setParent( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Parent ) throw (::com::sun::star::lang::NoSupportException, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
private:
- ::boost::scoped_ptr< UndoManager_Impl > m_pImpl;
+ std::unique_ptr< UndoManager_Impl > m_xImpl;
};
diff --git a/include/editeng/Trie.hxx b/include/editeng/Trie.hxx
index c8963d89401d..302c6a622739 100644
--- a/include/editeng/Trie.hxx
+++ b/include/editeng/Trie.hxx
@@ -12,9 +12,9 @@
#include <sal/types.h>
#include <rtl/ustring.hxx>
-#include <vector>
#include <editeng/editengdllapi.h>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
+#include <vector>
namespace editeng
{
@@ -24,7 +24,7 @@ struct TrieNode;
class EDITENG_DLLPUBLIC Trie
{
private:
- boost::scoped_ptr<TrieNode> mRoot;
+ std::unique_ptr<TrieNode> mRoot;
public:
Trie();
diff --git a/include/filter/msfilter/msdffimp.hxx b/include/filter/msfilter/msdffimp.hxx
index c85429eecd84..a6fdf663c0d4 100644
--- a/include/filter/msfilter/msdffimp.hxx
+++ b/include/filter/msfilter/msdffimp.hxx
@@ -27,7 +27,6 @@
#include <set>
#include <boost/shared_ptr.hpp>
-#include <boost/scoped_ptr.hpp>
#include <boost/ptr_container/ptr_vector.hpp>
#include <boost/ptr_container/ptr_set.hpp>
@@ -400,8 +399,8 @@ class MSFILTER_DLLPUBLIC SvxMSDffManager : public DffPropertyReader
{
FmFormModel* pFormModel;
SvxMSDffBLIPInfos* pBLIPInfos;
- ::boost::scoped_ptr<SvxMSDffShapeInfos_ByTxBxComp> m_pShapeInfosByTxBxComp;
- ::boost::scoped_ptr<SvxMSDffShapeInfos_ById> m_pShapeInfosById;
+ std::unique_ptr<SvxMSDffShapeInfos_ByTxBxComp> m_xShapeInfosByTxBxComp;
+ std::unique_ptr<SvxMSDffShapeInfos_ById> m_xShapeInfosById;
SvxMSDffShapeOrders* pShapeOrders;
sal_uLong nDefaultFontHeight;
sal_uInt32 nOffsDgg;
@@ -682,7 +681,7 @@ public:
const Rectangle& rGlobalChildRect );
inline const SvxMSDffShapeInfos_ById* GetShapeInfos( void ) const
- { return m_pShapeInfosById.get(); }
+ { return m_xShapeInfosById.get(); }
inline SvxMSDffShapeOrders* GetShapeOrders( void ) const
{ return pShapeOrders; }
diff --git a/include/framework/documentundoguard.hxx b/include/framework/documentundoguard.hxx
index 905038cedb0c..ab2f1c91b3b0 100644
--- a/include/framework/documentundoguard.hxx
+++ b/include/framework/documentundoguard.hxx
@@ -24,14 +24,10 @@
#include <com/sun/star/uno/XInterface.hpp>
-#include <boost/scoped_ptr.hpp>
-
+#include <memory>
namespace framework
{
-
-
-
//= DocumentUndoGuard
struct DocumentUndoGuard_Data;
@@ -51,7 +47,7 @@ namespace framework
~DocumentUndoGuard();
private:
- ::boost::scoped_ptr< DocumentUndoGuard_Data > m_pData;
+ std::unique_ptr< DocumentUndoGuard_Data > m_xData;
};
diff --git a/include/framework/undomanagerhelper.hxx b/include/framework/undomanagerhelper.hxx
index d4c12f3f23e8..1b94e3bf0251 100644
--- a/include/framework/undomanagerhelper.hxx
+++ b/include/framework/undomanagerhelper.hxx
@@ -26,7 +26,7 @@
#include <com/sun/star/document/XUndoManager.hpp>
#include <com/sun/star/util/XModifyListener.hpp>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
namespace svl
{
@@ -150,7 +150,7 @@ namespace framework
void removeModifyListener( const ::com::sun::star::uno::Reference< ::com::sun::star::util::XModifyListener >& i_listener );
private:
- ::boost::scoped_ptr< UndoManagerHelper_Impl > m_pImpl;
+ std::unique_ptr< UndoManagerHelper_Impl > m_xImpl;
};
diff --git a/include/o3tl/cow_wrapper.hxx b/include/o3tl/cow_wrapper.hxx
index 7f11c55c136e..e7ca302468e3 100644
--- a/include/o3tl/cow_wrapper.hxx
+++ b/include/o3tl/cow_wrapper.hxx
@@ -74,8 +74,8 @@ namespace o3tl
that, despite the fact that this template provides access to
the wrapped type via pointer-like methods
(<code>operator->()</code> and <code>operator*()</code>), it does
- <em>not</em> work like e.g. the boost pointer wrappers
- (shared_ptr, scoped_ptr, etc.). Internally, the cow_wrapper
+ <em>not</em> work like e.g. the std smart pointer wrappers
+ (shared_ptr, unique_ptr, etc.). Internally, the cow_wrapper
holds a by-value instance of the wrapped object. This is to
avoid one additional heap allocation, and providing access via
<code>operator->()</code>/<code>operator*()</code> is because
diff --git a/include/oox/core/filterbase.hxx b/include/oox/core/filterbase.hxx
index 5e91f600469c..3d10c08fbae6 100644
--- a/include/oox/core/filterbase.hxx
+++ b/include/oox/core/filterbase.hxx
@@ -36,8 +36,6 @@
#include <oox/helper/storagebase.hxx>
#include <oox/dllapi.h>
-#include <boost/scoped_ptr.hpp>
-
namespace com { namespace sun { namespace star {
namespace awt { struct DeviceInfo; }
namespace frame { class XFrame; }
@@ -284,7 +282,7 @@ private:
const ::com::sun::star::uno::Reference< ::com::sun::star::io::XStream >& rxOutStream ) const = 0;
private:
- boost::scoped_ptr< FilterBaseImpl > mxImpl;
+ std::unique_ptr< FilterBaseImpl > mxImpl;
};
diff --git a/include/oox/core/xmlfilterbase.hxx b/include/oox/core/xmlfilterbase.hxx
index a8c950e3ed59..b6bc9687b198 100644
--- a/include/oox/core/xmlfilterbase.hxx
+++ b/include/oox/core/xmlfilterbase.hxx
@@ -52,7 +52,7 @@ namespace oox {
namespace sax_fastparser {
class FastSerializerHelper;
- typedef boost::shared_ptr< FastSerializerHelper > FSHelperPtr;
+ typedef std::shared_ptr< FastSerializerHelper > FSHelperPtr;
}
namespace oox {
diff --git a/include/oox/crypto/DocumentDecryption.hxx b/include/oox/crypto/DocumentDecryption.hxx
index 1f2d3bc5bc25..b9bf2d449260 100644
--- a/include/oox/crypto/DocumentDecryption.hxx
+++ b/include/oox/crypto/DocumentDecryption.hxx
@@ -25,7 +25,7 @@
#include <oox/crypto/AgileEngine.hxx>
#include <oox/crypto/Standard2007Engine.hxx>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
#include <vector>
namespace oox {
@@ -44,7 +44,7 @@ private:
};
oox::ole::OleStorage& mrOleStorage;
- boost::scoped_ptr<CryptoEngine> mEngine;
+ std::unique_ptr<CryptoEngine> mEngine;
CryptoType mCryptoType;
bool readAgileEncryptionInfo( com::sun::star::uno::Reference< com::sun::star::io::XInputStream >& rStream );
diff --git a/include/sax/fshelper.hxx b/include/sax/fshelper.hxx
index 50248ce28ce6..293b0be4f4be 100644
--- a/include/sax/fshelper.hxx
+++ b/include/sax/fshelper.hxx
@@ -21,9 +21,9 @@
#define INCLUDED_SAX_FSHELPER_HXX
#include <com/sun/star/io/XOutputStream.hpp>
-#include <stdarg.h>
-#include <boost/shared_ptr.hpp>
#include <sax/fastattribs.hxx>
+#include <stdarg.h>
+#include <memory>
#define FSNS(namespc, element) ((namespc << 16) | element)
// Backwards compatibility for code that used FSEND to terminate the vararg.
@@ -184,7 +184,7 @@ private:
FastSaxSerializer* mpSerializer;
};
-typedef boost::shared_ptr< FastSerializerHelper > FSHelperPtr;
+typedef std::shared_ptr< FastSerializerHelper > FSHelperPtr;
}
diff --git a/include/sfx2/dispatch.hxx b/include/sfx2/dispatch.hxx
index 3b1476c3a0e2..c32ec1faf0a3 100644
--- a/include/sfx2/dispatch.hxx
+++ b/include/sfx2/dispatch.hxx
@@ -27,7 +27,6 @@
#include <sfx2/bindings.hxx>
#include <sfx2/viewfrm.hxx>
-#include <boost/scoped_ptr.hpp>
class SfxSlotServer;
class SfxShell;
@@ -72,7 +71,7 @@ enum SfxSlotFilterState
class SFX2_DLLPUBLIC SfxDispatcher
{
- boost::scoped_ptr<SfxDispatcher_Impl> pImp;
+ std::unique_ptr<SfxDispatcher_Impl> xImp;
private:
// Search for temporary evaluated Todos
diff --git a/include/sfx2/itemconnect.hxx b/include/sfx2/itemconnect.hxx
index 3e49921ae659..7167075e098b 100644
--- a/include/sfx2/itemconnect.hxx
+++ b/include/sfx2/itemconnect.hxx
@@ -25,16 +25,11 @@
#include <memory>
-#include <boost/scoped_ptr.hpp>
#include <sfx2/itemwrapper.hxx>
#include <sfx2/controlwrapper.hxx>
-
-
namespace sfx {
-
-
typedef int ItemConnFlags;
/** No special state for the connection. */
@@ -513,7 +508,7 @@ bool ItemControlConnection< ItemWrpT, ControlWrpT >::FillItemSet(
if( !pOldItem || !(maItemWrp.GetItemValue( *pOldItem ) == aNewValue) )
{
sal_uInt16 nWhich = ItemWrapperHelper::GetWhichId( rDestSet, maItemWrp.GetSlotId() );
- boost::scoped_ptr< ItemType > xItem(
+ std::unique_ptr< ItemType > xItem(
static_cast< ItemType* >( maItemWrp.GetDefaultItem( rDestSet ).Clone() ) );
xItem->SetWhich( nWhich );
maItemWrp.SetItemValue( *xItem, aNewValue );
diff --git a/include/sfx2/taskpane.hxx b/include/sfx2/taskpane.hxx
index 5495c0b0bc6d..dadbdf1d300f 100644
--- a/include/sfx2/taskpane.hxx
+++ b/include/sfx2/taskpane.hxx
@@ -27,7 +27,6 @@
#include <svtools/toolpanel/tabalignment.hxx>
#include <svtools/toolpanel/tabitemcontent.hxx>
-#include <boost/scoped_ptr.hpp>
#include <boost/optional.hpp>
namespace svt
@@ -126,7 +125,7 @@ namespace sfx2
virtual void GetFocus() SAL_OVERRIDE;
private:
- ::boost::scoped_ptr< ModuleTaskPane_Impl > m_pImpl;
+ std::unique_ptr<ModuleTaskPane_Impl> m_xImpl;
};
@@ -152,7 +151,7 @@ namespace sfx2
void ActivateToolPanel( const OUString& i_rPanelURL );
private:
- ::boost::scoped_ptr< TaskPaneController_Impl > m_pImpl;
+ std::unique_ptr<TaskPaneController_Impl> m_xImpl;
};
diff --git a/include/svl/asiancfg.hxx b/include/svl/asiancfg.hxx
index 0652a5dace12..127eb009a973 100644
--- a/include/svl/asiancfg.hxx
+++ b/include/svl/asiancfg.hxx
@@ -23,7 +23,7 @@
#include <sal/config.h>
#include <boost/noncopyable.hpp>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
#include <com/sun/star/uno/Sequence.hxx>
#include <sal/types.h>
#include <svl/svldllapi.h>
@@ -62,7 +62,7 @@ public:
private:
struct Impl;
- boost::scoped_ptr< Impl > impl_;
+ std::unique_ptr< Impl > impl_;
};
#endif
diff --git a/include/svl/undo.hxx b/include/svl/undo.hxx
index d0132daf9d6c..d9b12274aae5 100644
--- a/include/svl/undo.hxx
+++ b/include/svl/undo.hxx
@@ -23,9 +23,8 @@
#include <rtl/ustring.hxx>
#include <tools/rtti.hxx>
-#include <boost/scoped_ptr.hpp>
-
#include <limits>
+#include <memory>
struct MarkedUndoAction;
@@ -313,8 +312,8 @@ class SVL_DLLPUBLIC SfxUndoManager : public ::svl::IUndoManager
{
friend class SfxLinkUndoAction;
- ::boost::scoped_ptr< SfxUndoManager_Data >
- m_pData;
+ std::unique_ptr< SfxUndoManager_Data >
+ m_xData;
public:
SfxUndoManager( size_t nMaxUndoActionCount = 20 );
virtual ~SfxUndoManager();
diff --git a/include/svtools/DocumentInfoPreview.hxx b/include/svtools/DocumentInfoPreview.hxx
index ee671b7a0f8a..e75877588029 100644
--- a/include/svtools/DocumentInfoPreview.hxx
+++ b/include/svtools/DocumentInfoPreview.hxx
@@ -22,7 +22,6 @@
#include <sal/config.h>
-#include <boost/scoped_ptr.hpp>
#include <i18nlangtag/languagetag.hxx>
#include <com/sun/star/uno/Reference.hxx>
#include <svtools/svmedit2.hxx>
@@ -56,7 +55,7 @@ public:
private:
ExtMultiLineEdit m_pEditWin;
- boost::scoped_ptr< SvtDocInfoTable_Impl > m_pInfoTable;
+ std::unique_ptr< SvtDocInfoTable_Impl > m_xInfoTable;
LanguageTag m_aLanguageTag;
void insertEntry(OUString const & title, OUString const & value);
diff --git a/include/svtools/popupwindowcontroller.hxx b/include/svtools/popupwindowcontroller.hxx
index 27fbf710ac2d..d505e2f04dc2 100644
--- a/include/svtools/popupwindowcontroller.hxx
+++ b/include/svtools/popupwindowcontroller.hxx
@@ -25,7 +25,6 @@
#include <com/sun/star/lang/XServiceInfo.hpp>
#include <svtools/toolboxcontroller.hxx>
-#include <boost/scoped_ptr.hpp>
namespace vcl { class Window; }
@@ -69,7 +68,7 @@ public:
virtual ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > SAL_CALL createPopupWindow() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
virtual ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow > SAL_CALL createItemWindow( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XWindow >& Parent ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
private:
- boost::scoped_ptr< PopupWindowControllerImpl > mpImpl;
+ std::unique_ptr< PopupWindowControllerImpl > mxImpl;
};
} // namespace svt
diff --git a/include/svtools/ruler.hxx b/include/svtools/ruler.hxx
index 6c430dcc54e9..16d5d692594e 100644
--- a/include/svtools/ruler.hxx
+++ b/include/svtools/ruler.hxx
@@ -27,8 +27,6 @@
#include <vcl/virdev.hxx>
#include <vcl/field.hxx>
-#include <boost/scoped_ptr.hpp>
-
#include <svtools/accessibleruler.hxx>
class MouseEvent;
@@ -680,8 +678,8 @@ private:
Link maDoubleClickHdl;
Link maExtraDownHdl;
- boost::scoped_ptr<RulerSelection> mpCurrentHitTest;
- boost::scoped_ptr<RulerSelection> mpPreviousHitTest;
+ std::unique_ptr<RulerSelection> mxCurrentHitTest;
+ std::unique_ptr<RulerSelection> mxPreviousHitTest;
SvtRulerAccessible* pAccContext;
diff --git a/include/svtools/valueset.hxx b/include/svtools/valueset.hxx
index acb7a4e92ad7..baebae42db8c 100644
--- a/include/svtools/valueset.hxx
+++ b/include/svtools/valueset.hxx
@@ -25,8 +25,8 @@
#include <vcl/ctrl.hxx>
#include <vcl/virdev.hxx>
#include <vcl/timer.hxx>
+#include <memory>
#include <vector>
-#include <boost/scoped_ptr.hpp>
class MouseEvent;
class TrackingEvent;
@@ -177,7 +177,7 @@ to be set (before Show) with SetStyle().
*************************************************************************/
typedef std::vector<ValueSetItem*> ValueItemList;
-typedef boost::scoped_ptr<ValueSetItem> ValueSetItemPtr;
+typedef std::unique_ptr<ValueSetItem> ValueSetItemPtr;
// - ValueSet types -
#define WB_RADIOSEL ((WinBits)0x00008000)
@@ -201,7 +201,7 @@ private:
Timer maTimer;
ValueItemList mItemList;
ValueSetItemPtr mpNoneItem;
- boost::scoped_ptr<ScrollBar> mpScrollBar;
+ std::unique_ptr<ScrollBar> mxScrollBar;
Rectangle maNoneItemRect;
Rectangle maItemListRect;
long mnItemWidth;
diff --git a/include/svx/dialcontrol.hxx b/include/svx/dialcontrol.hxx
index b7daff733d68..38b60e3f6f4e 100644
--- a/include/svx/dialcontrol.hxx
+++ b/include/svx/dialcontrol.hxx
@@ -25,8 +25,6 @@
#include <sfx2/itemconnect.hxx>
#include <svx/svxdllapi.h>
-#include <boost/scoped_ptr.hpp>
-
class NumericField;
namespace svx {
@@ -128,9 +126,9 @@ public:
protected:
struct DialControl_Impl
{
- ::boost::scoped_ptr<DialControlBmp> mpBmpEnabled;
- ::boost::scoped_ptr<DialControlBmp> mpBmpDisabled;
- ::boost::scoped_ptr<DialControlBmp> mpBmpBuffered;
+ std::unique_ptr<DialControlBmp> mxBmpEnabled;
+ std::unique_ptr<DialControlBmp> mxBmpDisabled;
+ std::unique_ptr<DialControlBmp> mxBmpBuffered;
Link maModifyHdl;
NumericField* mpLinkField;
sal_Int32 mnLinkedFieldValueMultiplyer;
diff --git a/include/svx/framelinkarray.hxx b/include/svx/framelinkarray.hxx
index f177215ed8c7..0fbaf43870c7 100644
--- a/include/svx/framelinkarray.hxx
+++ b/include/svx/framelinkarray.hxx
@@ -20,13 +20,11 @@
#ifndef INCLUDED_SVX_FRAMELINKARRAY_HXX
#define INCLUDED_SVX_FRAMELINKARRAY_HXX
-#include <svx/framelink.hxx>
#include <drawinglayer/processor2d/baseprocessor2d.hxx>
-
-#include <vector>
+#include <svx/framelink.hxx>
#include <svx/svxdllapi.h>
-
-#include <boost/scoped_ptr.hpp>
+#include <memory>
+#include <vector>
namespace svx {
namespace frame {
@@ -380,7 +378,7 @@ public:
private:
- typedef boost::scoped_ptr<ArrayImpl> ArrayImplPtr;
+ typedef std::unique_ptr<ArrayImpl> ArrayImplPtr;
ArrayImplPtr mxImpl;
};
diff --git a/include/svx/ruler.hxx b/include/svx/ruler.hxx
index 60bc63e0e786..ff44a6c45d64 100644
--- a/include/svx/ruler.hxx
+++ b/include/svx/ruler.hxx
@@ -24,8 +24,8 @@
#include <svl/lstner.hxx>
#include <svx/svxdllapi.h>
-#include <boost/scoped_ptr.hpp>
#include <boost/scoped_array.hpp>
+#include <memory>
class SvxProtectItem;
class SvxRulerItem;
@@ -47,19 +47,19 @@ class SVX_DLLPUBLIC SvxRuler: public Ruler, public SfxListener
using Window::Notify;
SvxRulerItem** pCtrlItem;
- boost::scoped_ptr<SvxLongLRSpaceItem> mpLRSpaceItem; // left and right edge
- boost::scoped_ptr<SfxRectangleItem> mpMinMaxItem; // maxima for dragging
- boost::scoped_ptr<SvxLongULSpaceItem> mpULSpaceItem; // upper and lower edge
- boost::scoped_ptr<SvxTabStopItem> mpTabStopItem; // tab stops
- boost::scoped_ptr<SvxLRSpaceItem> mpParaItem; // paragraphs
- boost::scoped_ptr<SvxLRSpaceItem> mpParaBorderItem; // border distance
- boost::scoped_ptr<SvxPagePosSizeItem> mpPagePosItem; // page distance to the rule
- boost::scoped_ptr<SvxColumnItem> mpColumnItem; // columns
- boost::scoped_ptr<SvxObjectItem> mpObjectItem; // object
+ std::unique_ptr<SvxLongLRSpaceItem> mxLRSpaceItem; // left and right edge
+ std::unique_ptr<SfxRectangleItem> mxMinMaxItem; // maxima for dragging
+ std::unique_ptr<SvxLongULSpaceItem> mxULSpaceItem; // upper and lower edge
+ std::unique_ptr<SvxTabStopItem> mxTabStopItem; // tab stops
+ std::unique_ptr<SvxLRSpaceItem> mxParaItem; // paragraphs
+ std::unique_ptr<SvxLRSpaceItem> mxParaBorderItem; // border distance
+ std::unique_ptr<SvxPagePosSizeItem> mxPagePosItem; // page distance to the rule
+ std::unique_ptr<SvxColumnItem> mxColumnItem; // columns
+ std::unique_ptr<SvxObjectItem> mxObjectItem; // object
vcl::Window* pEditWin;
- boost::scoped_ptr<SvxRuler_Impl> mpRulerImpl;
+ std::unique_ptr<SvxRuler_Impl> mxRulerImpl;
bool bAppSetNullOffset :1;
bool bHorz :1;
diff --git a/include/svx/sidebar/Popup.hxx b/include/svx/sidebar/Popup.hxx
index 2e5d7910fe81..e11e8c1ee6b0 100644
--- a/include/svx/sidebar/Popup.hxx
+++ b/include/svx/sidebar/Popup.hxx
@@ -24,7 +24,6 @@
#include <tools/link.hxx>
#include <boost/function.hpp>
-#include <boost/scoped_ptr.hpp>
namespace vcl { class Window; }
class ToolBox;
@@ -77,7 +76,7 @@ public :
void SetPopupModeEndHandler (const ::boost::function<void(void)>& rCallback);
protected:
- ::boost::scoped_ptr<PopupControl> mpControl;
+ std::unique_ptr<PopupControl> mxControl;
/** Make sure that both PopupContainer and PopupControl objects
exist. Calls the maControlCreator functor if necessary.
@@ -94,7 +93,7 @@ private:
::boost::function<PopupControl*(PopupContainer*)> maControlCreator;
::boost::function<void(void)> maPopupModeEndCallback;
const ::rtl::OUString msAccessibleName;
- ::boost::scoped_ptr<PopupContainer> mpContainer;
+ std::unique_ptr<PopupContainer> mxContainer;
DECL_LINK(PopupModeEndHandler, void*);
};
diff --git a/include/svx/svdomedia.hxx b/include/svx/svdomedia.hxx
index 8a329347ddf9..b2a662dc78b9 100644
--- a/include/svx/svdomedia.hxx
+++ b/include/svx/svdomedia.hxx
@@ -81,7 +81,7 @@ protected:
private:
struct Impl;
- ::boost::scoped_ptr<Impl> m_pImpl;
+ std::unique_ptr<Impl> m_xImpl;
};
#endif // INCLUDED_SVX_SVDOMEDIA_HXX
diff --git a/include/svx/svdpage.hxx b/include/svx/svdpage.hxx
index 03387e2b79ad..868dc49ee801 100644
--- a/include/svx/svdpage.hxx
+++ b/include/svx/svdpage.hxx
@@ -29,7 +29,6 @@
#include <cppuhelper/weakref.hxx>
#include <svx/svdtypes.hxx>
#include <svx/svdlayer.hxx>
-#include <vector>
#include <svx/sdrpageuser.hxx>
#include <svx/sdr/contact/viewobjectcontactredirector.hxx>
#include <svx/sdrmasterpagedescriptor.hxx>
@@ -37,11 +36,11 @@
#include <com/sun/star/container/XIndexAccess.hpp>
#include <com/sun/star/drawing/XDrawPage.hpp>
#include <svx/svdobj.hxx>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
+#include <vector>
// predefines
-
namespace reportdesign { class OSection; }
namespace sdr { namespace contact { class ViewContact; }}
class SdrPage;
@@ -213,7 +212,7 @@ public:
const sal_uInt32 nNewNavigationPosition);
/** Return the object for the given navigation position. When there is
- a user defined navigation order, i.e. mpNavigationOrder is not NULL,
+ a user defined navigation order, i.e. mxNavigationOrder is not NULL,
then that is used to look up the object. Otherwise the z-order is
used by looking up the object in maList.
@param nNavigationPosition
@@ -229,7 +228,7 @@ public:
void ClearObjectNavigationOrder (void);
/** Set the navigation position of all SdrObjects to their position in
- the mpNavigationOrder list. This method returns immediately when no
+ the mxNavigationOrder list. This method returns immediately when no
update is necessary.
@return
This method returns <TRUE/> when the navigation positions stored
@@ -258,7 +257,7 @@ private:
class WeakSdrObjectContainerType;
/// This list, if it exists, defines the navigation order. If it does
/// not exist then maList defines the navigation order.
- ::boost::scoped_ptr<WeakSdrObjectContainerType> mpNavigationOrder;
+ std::unique_ptr<WeakSdrObjectContainerType> mxNavigationOrder;
/// This flag is <TRUE/> when the mpNavigation list has been changed but
/// the indices of the referenced SdrObjects still have their old values.
diff --git a/include/svx/tbcontrl.hxx b/include/svx/tbcontrl.hxx
index 2f90a130b6b6..8db6a02625d3 100644
--- a/include/svx/tbcontrl.hxx
+++ b/include/svx/tbcontrl.hxx
@@ -135,9 +135,9 @@
#include <sfx2/tbxctrl.hxx>
#include <svx/strarray.hxx>
#include <svx/svxdllapi.h>
-#include <boost/scoped_ptr.hpp>
#include <com/sun/star/awt/FontDescriptor.hpp>
#include <svx/PaletteManager.hxx>
+#include <memory>
// important im tbxctrls.hxx created HeDaBu !!!
class SvxLineItem;
@@ -236,7 +236,7 @@ class SVX_DLLPUBLIC SvxColorToolBoxControl : public SfxToolBoxControl
{
using SfxToolBoxControl::StateChanged;
- ::boost::scoped_ptr< ::svx::ToolboxButtonColorUpdater > pBtnUpdater;
+ std::unique_ptr< ::svx::ToolboxButtonColorUpdater > m_xBtnUpdater;
PaletteManager mPaletteManager;
BorderColorStatus maBorderColorStatus;
bool bSidebarType;
diff --git a/include/svx/zoomsliderctrl.hxx b/include/svx/zoomsliderctrl.hxx
index f35f825383a4..e0eca276eebd 100644
--- a/include/svx/zoomsliderctrl.hxx
+++ b/include/svx/zoomsliderctrl.hxx
@@ -22,16 +22,15 @@
#include <sfx2/stbitem.hxx>
#include <svx/svxdllapi.h>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
// class SvxZoomSliderControl ----------------------------------------
-
class SVX_DLLPUBLIC SvxZoomSliderControl : public SfxStatusBarControl
{
private:
struct SvxZoomSliderControl_Impl;
- boost::scoped_ptr<SvxZoomSliderControl_Impl> mpImpl;
+ std::unique_ptr<SvxZoomSliderControl_Impl> mxImpl;
sal_uInt16 Offset2Zoom( long nOffset ) const;
long Zoom2Offset( sal_uInt16 nZoom ) const;
diff --git a/include/toolkit/awt/animatedimagespeer.hxx b/include/toolkit/awt/animatedimagespeer.hxx
index 4c9e63a797b0..15dcac26e7eb 100644
--- a/include/toolkit/awt/animatedimagespeer.hxx
+++ b/include/toolkit/awt/animatedimagespeer.hxx
@@ -27,9 +27,8 @@
#include <cppuhelper/implbase3.hxx>
-#include <boost/scoped_ptr.hpp>
#include <boost/noncopyable.hpp>
-
+#include <memory>
namespace toolkit
{
@@ -87,7 +86,7 @@ namespace toolkit
void impl_updateImages_nolck( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& i_animatedImages );
private:
- ::boost::scoped_ptr< AnimatedImagesPeer_Data > m_pData;
+ std::unique_ptr< AnimatedImagesPeer_Data > m_xData;
};
diff --git a/include/toolkit/controls/animatedimages.hxx b/include/toolkit/controls/animatedimages.hxx
index 813f1919abd7..1a31b2aaa80c 100644
--- a/include/toolkit/controls/animatedimages.hxx
+++ b/include/toolkit/controls/animatedimages.hxx
@@ -22,15 +22,11 @@
#include <toolkit/controls/unocontrolbase.hxx>
#include <toolkit/controls/unocontrolmodel.hxx>
-
#include <com/sun/star/awt/XAnimatedImages.hpp>
#include <com/sun/star/container/XContainerListener.hpp>
#include <com/sun/star/uno/XComponentContext.hpp>
-
#include <cppuhelper/implbase1.hxx>
-
-#include <boost/scoped_ptr.hpp>
-
+#include <memory>
namespace toolkit
{
@@ -83,8 +79,7 @@ namespace toolkit
void SAL_CALL setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const ::com::sun::star::uno::Any& rValue ) throw (::com::sun::star::uno::Exception, std::exception) SAL_OVERRIDE;
private:
- ::boost::scoped_ptr< AnimatedImagesControlModel_Data >
- m_pData;
+ std::unique_ptr< AnimatedImagesControlModel_Data > m_xData;
};
diff --git a/include/toolkit/controls/unocontrols.hxx b/include/toolkit/controls/unocontrols.hxx
index 079f70671565..e87800bef0b4 100644
--- a/include/toolkit/controls/unocontrols.hxx
+++ b/include/toolkit/controls/unocontrols.hxx
@@ -55,9 +55,9 @@
#include <comphelper/uno3.hxx>
#include <list>
+#include <memory>
#include <vector>
-#include <boost/scoped_ptr.hpp>
#include <boost/optional.hpp>
#define UNO_NAME_GRAPHOBJ_URLPREFIX "vnd.sun.star.GraphicObject:"
@@ -825,8 +825,8 @@ private:
void impl_setStringItemList_nolck( const ::std::vector< OUString >& i_rStringItems );
protected:
- ::boost::scoped_ptr< UnoControlListBoxModel_Data > m_pData;
- ::cppu::OInterfaceContainerHelper m_aItemListListeners;
+ std::unique_ptr<UnoControlListBoxModel_Data> m_xData;
+ ::cppu::OInterfaceContainerHelper m_aItemListListeners;
};
diff --git a/include/unotools/atom.hxx b/include/unotools/atom.hxx
index 96f1574ecae1..fdc656e5b69a 100644
--- a/include/unotools/atom.hxx
+++ b/include/unotools/atom.hxx
@@ -24,7 +24,6 @@
#include <osl/mutex.hxx>
#include <com/sun/star/util/XAtomServer.hpp>
#include <cppuhelper/implbase1.hxx>
-#include <boost/functional/hash.hpp>
#include <list>
#include <unordered_map>
@@ -40,9 +39,9 @@ namespace utl {
class AtomProvider
{
- int m_nAtoms;
- std::unordered_map< int, OUString, ::boost::hash< int > > m_aStringMap;
- std::unordered_map< OUString, int, OUStringHash > m_aAtomMap;
+ int m_nAtoms;
+ std::unordered_map<int, OUString> m_aStringMap;
+ std::unordered_map<OUString, int, OUStringHash> m_aAtomMap;
public:
AtomProvider();
~AtomProvider();
@@ -53,7 +52,7 @@ namespace utl {
class UNOTOOLS_DLLPUBLIC MultiAtomProvider
{
- std::unordered_map< int, AtomProvider*, ::boost::hash< int > > m_aAtomLists;
+ std::unordered_map<int, AtomProvider*> m_aAtomLists;
public:
MultiAtomProvider();
~MultiAtomProvider();
diff --git a/include/unotools/closeveto.hxx b/include/unotools/closeveto.hxx
index 9beb0b55361e..1079c3597341 100644
--- a/include/unotools/closeveto.hxx
+++ b/include/unotools/closeveto.hxx
@@ -21,16 +21,13 @@
#define INCLUDED_UNOTOOLS_CLOSEVETO_HXX
#include <unotools/unotoolsdllapi.h>
-
#include <com/sun/star/uno/XInterface.hpp>
-
-#include <boost/scoped_ptr.hpp>
+#include <memory>
namespace utl
{
//= CloseVeto
-
struct CloseVeto_Data;
/** will add a XCloseListener to a given component, and veto its closing as long as the <code>CloseVeto</code>
instance is alive.
@@ -45,7 +42,7 @@ namespace utl
~CloseVeto();
private:
- ::boost::scoped_ptr< CloseVeto_Data > m_pData;
+ std::unique_ptr< CloseVeto_Data > m_xData;
};
} // namespace dbaui
diff --git a/include/unotools/localedatawrapper.hxx b/include/unotools/localedatawrapper.hxx
index 77e580fb37da..219d5ebc52fd 100644
--- a/include/unotools/localedatawrapper.hxx
+++ b/include/unotools/localedatawrapper.hxx
@@ -21,7 +21,6 @@
#define INCLUDED_UNOTOOLS_LOCALEDATAWRAPPER_HXX
#include <boost/noncopyable.hpp>
-#include <boost/shared_ptr.hpp>
#include <com/sun/star/i18n/XLocaleData4.hpp>
#include <com/sun/star/i18n/LocaleItem.hpp>
#include <com/sun/star/i18n/reservedWords.hpp>
@@ -29,6 +28,7 @@
#include <i18nlangtag/languagetag.hxx>
#include <unotools/readwritemutexguard.hxx>
#include <unotools/unotoolsdllapi.h>
+#include <memory>
namespace com { namespace sun { namespace star {
namespace uno {
@@ -54,14 +54,14 @@ class UNOTOOLS_DLLPUBLIC LocaleDataWrapper : private boost::noncopyable
{
static sal_uInt8 nLocaleDataChecking; // 0:=dontknow, 1:=yes, 2:=no
- ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
- ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XLocaleData4 > xLD;
- LanguageTag maLanguageTag;
- ::boost::shared_ptr< ::com::sun::star::i18n::Calendar2 > xDefaultCalendar;
- ::com::sun::star::i18n::LocaleDataItem aLocaleDataItem;
+ ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
+ ::com::sun::star::uno::Reference< ::com::sun::star::i18n::XLocaleData4 > xLD;
+ LanguageTag maLanguageTag;
+ std::shared_ptr< ::com::sun::star::i18n::Calendar2 > xDefaultCalendar;
+ ::com::sun::star::i18n::LocaleDataItem aLocaleDataItem;
::com::sun::star::uno::Sequence< OUString > aReservedWordSeq;
::com::sun::star::uno::Sequence< OUString > aDateAcceptancePatterns;
- ::com::sun::star::uno::Sequence< sal_Int32 > aGrouping;
+ ::com::sun::star::uno::Sequence< sal_Int32 > aGrouping;
// cached items
OUString aLocaleItem[::com::sun::star::i18n::LocaleItem::COUNT];
OUString aReservedWord[::com::sun::star::i18n::reservedWords::COUNT];
@@ -170,7 +170,7 @@ public:
MeasurementSystem mapMeasurementStringToEnum( const OUString& rMS ) const;
/// Convenience method to obtain the default calendar.
- const ::boost::shared_ptr< ::com::sun::star::i18n::Calendar2 > getDefaultCalendar() const;
+ const std::shared_ptr< ::com::sun::star::i18n::Calendar2 > getDefaultCalendar() const;
/// Convenience method to obtain the day names of the default calendar.
const ::com::sun::star::uno::Sequence< ::com::sun::star::i18n::CalendarItem2 > getDefaultCalendarDays() const;
diff --git a/include/unotools/sharedunocomponent.hxx b/include/unotools/sharedunocomponent.hxx
index ff932b69bba9..9a39134f6d26 100644
--- a/include/unotools/sharedunocomponent.hxx
+++ b/include/unotools/sharedunocomponent.hxx
@@ -21,10 +21,9 @@
#define INCLUDED_UNOTOOLS_SHAREDUNOCOMPONENT_HXX
#include <unotools/unotoolsdllapi.h>
-
-#include <boost/shared_ptr.hpp>
#include <com/sun/star/uno/Reference.hxx>
#include <rtl/ref.hxx>
+#include <memory>
namespace com { namespace sun { namespace star {
namespace lang {
@@ -139,10 +138,10 @@ namespace utl
{
private:
typedef COMPONENT Component;
- typedef ::boost::shared_ptr< Component > ComponentPointer;
+ typedef std::shared_ptr<Component> ComponentPointer;
private:
- ComponentPointer m_pComponent;
+ ComponentPointer m_xComponent;
::com::sun::star::uno::Reference< INTERFACE > m_xTypedComponent;
public:
@@ -208,24 +207,24 @@ namespace utl
INTERFACE* SAL_CALL operator->() const;
- inline operator const ::com::sun::star::uno::Reference< INTERFACE >&() const
+ operator const ::com::sun::star::uno::Reference< INTERFACE >&() const
{
return m_xTypedComponent;
}
- inline const ::com::sun::star::uno::Reference< INTERFACE >& getTyped() const
+ const ::com::sun::star::uno::Reference< INTERFACE >& getTyped() const
{
return m_xTypedComponent;
}
- inline bool is() const
+ bool is() const
{
return m_xTypedComponent.is();
}
- inline void clear()
+ void clear()
{
- m_pComponent.reset();
+ m_xComponent.reset();
m_xTypedComponent.clear();
}
};
@@ -240,7 +239,7 @@ namespace utl
template < class INTERFACE, class COMPONENT >
void SharedUNOComponent< INTERFACE, COMPONENT >::reset( const ::com::sun::star::uno::Reference< INTERFACE >& _rxComponent, AssignmentMode _eMode )
{
- m_pComponent.reset( _eMode == TakeOwnership ? new COMPONENT( _rxComponent ) : NULL );
+ m_xComponent.reset(_eMode == TakeOwnership ? new COMPONENT( _rxComponent ) : NULL);
m_xTypedComponent = _rxComponent;
}
diff --git a/include/unotools/useroptions.hxx b/include/unotools/useroptions.hxx
index 7a9cee52e4e7..e518d9f2c0d9 100644
--- a/include/unotools/useroptions.hxx
+++ b/include/unotools/useroptions.hxx
@@ -23,8 +23,7 @@
#include <unotools/configitem.hxx>
#include <osl/mutex.hxx>
#include <unotools/options.hxx>
-#include <boost/shared_ptr.hpp>
-#include <boost/weak_ptr.hpp>
+#include <memory>
// define ----------------------------------------------------------------
@@ -81,8 +80,8 @@ public:
private:
class Impl;
- boost::shared_ptr<Impl> pImpl;
- static boost::weak_ptr<Impl> pSharedImpl;
+ std::shared_ptr<Impl> xImpl;
+ static std::weak_ptr<Impl> xSharedImpl;
private:
class ChangeListener;
};
diff --git a/include/vcl/builder.hxx b/include/vcl/builder.hxx
index ef8264bdd299..0622f0922adc 100644
--- a/include/vcl/builder.hxx
+++ b/include/vcl/builder.hxx
@@ -20,7 +20,6 @@
#include <set>
#include <stack>
#include <vector>
-#include <boost/noncopyable.hpp>
#ifdef check
# //some problem with MacOSX and a check define
# undef check
@@ -40,7 +39,7 @@ class VclExpander;
class VclMultiLineEdit;
namespace xmlreader { class XmlReader; }
-class VCL_DLLPUBLIC VclBuilder: private boost::noncopyable
+class VCL_DLLPUBLIC VclBuilder
{
public:
typedef std::map<OString, OString> stringmap;
@@ -115,6 +114,9 @@ public:
css::uno::Reference<css::frame::XFrame> getFrame() { return m_xFrame; }
private:
+ VclBuilder(const VclBuilder&) SAL_DELETED_FUNCTION;
+ VclBuilder& operator=(const VclBuilder&) SAL_DELETED_FUNCTION;
+
typedef boost::ptr_map<OUString, osl::Module> ModuleMap;
//We store these until the builder is deleted, that way we can use the
diff --git a/include/vcl/button.hxx b/include/vcl/button.hxx
index 3ab556ddfe50..20f56710828b 100644
--- a/include/vcl/button.hxx
+++ b/include/vcl/button.hxx
@@ -273,12 +273,10 @@ public:
// - RadioButton -
-
-
class VCL_DLLPUBLIC RadioButton : public Button
{
private:
- boost::shared_ptr< std::vector<RadioButton*> > m_xGroup;
+ std::shared_ptr< std::vector<RadioButton*> > m_xGroup;
Rectangle maStateRect;
Rectangle maMouseRect;
Image maImage;
diff --git a/include/vcl/opengl/OpenGLContext.hxx b/include/vcl/opengl/OpenGLContext.hxx
index 02769231db34..0e98da6a6878 100644
--- a/include/vcl/opengl/OpenGLContext.hxx
+++ b/include/vcl/opengl/OpenGLContext.hxx
@@ -52,7 +52,6 @@ class NSOpenGLView;
#endif
#include <vcl/vclopengl_dllapi.hxx>
-#include <boost/scoped_ptr.hpp>
#include <boost/ptr_container/ptr_map.hpp>
#include <vcl/window.hxx>
#include <tools/gen.hxx>
@@ -250,10 +249,10 @@ private:
#endif
GLWindow m_aGLWin;
- boost::scoped_ptr<vcl::Window> m_pWindow;
- vcl::Window* mpWindow; //points to m_pWindow or the parent window, don't delete it
+ std::unique_ptr<vcl::Window> m_xWindow;
+ vcl::Window* mpWindow; //points to m_xWindow or the parent window, don't delete it
SystemChildWindow* m_pChildWindow;
- boost::scoped_ptr<SystemChildWindow> m_pChildWindowGC;
+ std::unique_ptr<SystemChildWindow> m_xChildWindowGC;
bool mbInitialized;
int mnRefCount;
bool mbRequestLegacyContext;
diff --git a/include/vcl/openglwin.hxx b/include/vcl/openglwin.hxx
index c95b02d5261a..9724eb3d9ffd 100644
--- a/include/vcl/openglwin.hxx
+++ b/include/vcl/openglwin.hxx
@@ -14,8 +14,6 @@
#include <vcl/syschild.hxx>
#include <vcl/vclopengl_dllapi.hxx>
-#include <boost/scoped_ptr.hpp>
-
class OpenGLContext;
class OpenGLWindowImpl;
@@ -49,7 +47,7 @@ public:
virtual void Command( const CommandEvent& rCEvt ) SAL_OVERRIDE;
private:
- boost::scoped_ptr<OpenGLWindowImpl> mpImpl;
+ std::unique_ptr<OpenGLWindowImpl> mxImpl;
IRenderer* mpRenderer;
Point maStartPoint;
diff --git a/include/vcl/outdev.hxx b/include/vcl/outdev.hxx
index 6a2aaa2ea85e..ec1063b6b717 100644
--- a/include/vcl/outdev.hxx
+++ b/include/vcl/outdev.hxx
@@ -43,8 +43,6 @@
#include <unotools/fontdefs.hxx>
-#include <boost/noncopyable.hpp>
-#include <boost/scoped_ptr.hpp>
#ifdef check
# //some problem with MacOSX and a check define
# undef check
@@ -54,6 +52,7 @@
#include <com/sun/star/drawing/LineCap.hpp>
#include <com/sun/star/uno/Reference.h>
+#include <memory>
#include <vector>
#if defined UNX
@@ -250,7 +249,7 @@ extern const sal_uLong nVCLBLut[ 6 ];
extern const sal_uLong nVCLDitherLut[ 256 ];
extern const sal_uLong nVCLLut[ 256 ];
-class VCL_DLLPUBLIC OutputDevice: private boost::noncopyable
+class VCL_DLLPUBLIC OutputDevice
{
friend class Printer;
friend class VirtualDevice;
@@ -260,6 +259,9 @@ class VCL_DLLPUBLIC OutputDevice: private boost::noncopyable
friend void ImplHandleResize( vcl::Window* pWindow, long nNewWidth, long nNewHeight );
private:
+ OutputDevice(const OutputDevice&) SAL_DELETED_FUNCTION;
+ OutputDevice& operator=(const OutputDevice&) SAL_DELETED_FUNCTION;
+
mutable SalGraphics* mpGraphics; ///< Graphics context to draw on
mutable OutputDevice* mpPrevGraphics; ///< Previous output device in list
mutable OutputDevice* mpNextGraphics; ///< Next output device in list
@@ -316,7 +318,7 @@ private:
TextAlign meTextAlign;
RasterOp meRasterOp;
Wallpaper maBackground;
- boost::scoped_ptr<AllSettings> mxSettings;
+ std::unique_ptr<AllSettings> mxSettings;
MapMode maMapMode;
Point maRefPoint;
sal_uInt16 mnAntialiasing;
diff --git a/include/vcl/pdfwriter.hxx b/include/vcl/pdfwriter.hxx
index 5b4b35d0951e..f8c1ff55b479 100644
--- a/include/vcl/pdfwriter.hxx
+++ b/include/vcl/pdfwriter.hxx
@@ -35,8 +35,6 @@
#include <com/sun/star/security/XCertificate.hpp>
#include <com/sun/star/lang/Locale.hpp>
-#include <boost/scoped_ptr.hpp>
-
#include <list>
#include <vector>
#include <set>
@@ -77,7 +75,7 @@ class VCL_DLLPUBLIC PDFOutputStream
class VCL_DLLPUBLIC PDFWriter
{
- boost::scoped_ptr<PDFWriterImpl> pImplementation;
+ std::unique_ptr<PDFWriterImpl> xImplementation;
public:
// extended line info
enum CapType { capButt, capRound, capSquare };
diff --git a/include/vcl/region.hxx b/include/vcl/region.hxx
index b182d36b8848..60090cea5122 100644
--- a/include/vcl/region.hxx
+++ b/include/vcl/region.hxx
@@ -22,9 +22,8 @@
#include <tools/gen.hxx>
#include <vcl/dllapi.h>
-
#include <basegfx/polygon/b2dpolypolygon.hxx>
-#include <boost/shared_ptr.hpp>
+#include <memory>
class ImplRegionBand;
class RegionBand;
@@ -34,9 +33,9 @@ namespace vcl { class Window; }
class OutputDevice;
class Bitmap;
-typedef boost::shared_ptr< RegionBand > RegionBandPtr;
-typedef boost::shared_ptr< tools::PolyPolygon > PolyPolygonPtr;
-typedef boost::shared_ptr< basegfx::B2DPolyPolygon > B2DPolyPolygonPtr;
+typedef std::shared_ptr< RegionBand > RegionBandPtr;
+typedef std::shared_ptr< tools::PolyPolygon > PolyPolygonPtr;
+typedef std::shared_ptr< basegfx::B2DPolyPolygon > B2DPolyPolygonPtr;
typedef std::vector< Rectangle > RectangleVector;
namespace vcl {
diff --git a/include/vcl/svapp.hxx b/include/vcl/svapp.hxx
index 9fc2d917f079..7de317f5eee6 100644
--- a/include/vcl/svapp.hxx
+++ b/include/vcl/svapp.hxx
@@ -1623,7 +1623,6 @@ namespace vcl
/** guard class that uses tryToAcquire() and has isAcquired() to check
*/
class SolarMutexTryAndBuyGuard
- : private boost::noncopyable
{
private:
bool m_isAcquired;
@@ -1632,6 +1631,9 @@ class SolarMutexTryAndBuyGuard
#endif
comphelper::SolarMutex& m_rSolarMutex;
+ SolarMutexTryAndBuyGuard(const SolarMutexTryAndBuyGuard&) SAL_DELETED_FUNCTION;
+ SolarMutexTryAndBuyGuard& operator=(const SolarMutexTryAndBuyGuard&) SAL_DELETED_FUNCTION;
+
public:
SolarMutexTryAndBuyGuard()
diff --git a/include/vcl/svgdata.hxx b/include/vcl/svgdata.hxx
index d4173f9182d1..15d27565b670 100644
--- a/include/vcl/svgdata.hxx
+++ b/include/vcl/svgdata.hxx
@@ -22,14 +22,11 @@
#include <basegfx/range/b2drange.hxx>
#include <boost/shared_array.hpp>
-#include <boost/shared_ptr.hpp>
-#include <boost/utility.hpp>
#include <com/sun/star/graphic/XPrimitive2D.hpp>
#include <vcl/bitmapex.hxx>
#include <rtl/ustring.hxx>
-
typedef boost::shared_array< sal_uInt8 > SvgDataArray;
typedef ::com::sun::star::uno::Reference< ::com::sun::star::graphic::XPrimitive2D > Primitive2DReference;
typedef ::com::sun::star::uno::Sequence< Primitive2DReference > Primitive2DSequence;
@@ -44,8 +41,7 @@ BitmapEx VCL_DLLPUBLIC convertPrimitive2DSequenceToBitmapEx(
const sal_uInt32 nMaximumQuadraticPixels = 500000);
-
-class VCL_DLLPUBLIC SvgData : private boost::noncopyable
+class VCL_DLLPUBLIC SvgData
{
private:
// the file and length
@@ -64,6 +60,9 @@ private:
void ensureReplacement();
void ensureSequenceAndRange();
+ SvgData(const SvgData&) SAL_DELETED_FUNCTION;
+ SvgData& operator=(const SvgData&) SAL_DELETED_FUNCTION;
+
public:
SvgData(const SvgDataArray& rSvgDataArray, sal_uInt32 nSvgDataArrayLength, const OUString& rPath);
SvgData(const OUString& rPath);
@@ -79,7 +78,7 @@ public:
const BitmapEx& getReplacement() const;
};
-typedef boost::shared_ptr< SvgData > SvgDataPtr;
+typedef std::shared_ptr< SvgData > SvgDataPtr;
#endif // INCLUDED_VCL_SVGDATA_HXX
diff --git a/include/xmloff/txtimp.hxx b/include/xmloff/txtimp.hxx
index 592c8343bb51..43b9315bef54 100644
--- a/include/xmloff/txtimp.hxx
+++ b/include/xmloff/txtimp.hxx
@@ -25,9 +25,9 @@
#include <com/sun/star/uno/Reference.h>
#include <map>
+#include <memory>
#include <boost/utility.hpp>
#include <boost/shared_ptr.hpp>
-#include <boost/scoped_ptr.hpp>
#include <xmloff/xmltkmap.hxx>
#include <rtl/ref.hxx>
@@ -371,7 +371,7 @@ class XMLOFF_DLLPUBLIC XMLTextImportHelper : public salhelper::SimpleReferenceOb
{
private:
struct Impl;
- boost::scoped_ptr<Impl> m_pImpl;
+ std::unique_ptr<Impl> m_xImpl;
/// ugly, but implementation of this is in XMLPropertyBackpatcher.cxx
struct BackpatcherImpl;
::boost::shared_ptr<BackpatcherImpl> m_pBackpatcherImpl;
diff --git a/include/xmloff/txtparae.hxx b/include/xmloff/txtparae.hxx
index 376fe42e9487..ca0c3b43f3b7 100644
--- a/include/xmloff/txtparae.hxx
+++ b/include/xmloff/txtparae.hxx
@@ -30,8 +30,8 @@
#include <xmloff/styleexp.hxx>
#include <xmloff/xmltoken.hxx>
#include <xmloff/SinglePropertySetInfoCache.hxx>
+#include <memory>
#include <vector>
-#include <boost/scoped_ptr.hpp>
class XMLTextListsHelper;
class SvXMLExport;
@@ -66,7 +66,7 @@ namespace xmloff
class XMLOFF_DLLPUBLIC XMLTextParagraphExport : public XMLStyleExport
{
struct Impl;
- ::boost::scoped_ptr<Impl> m_pImpl;
+ std::unique_ptr<Impl> m_xImpl;
// SvXMLExport& rExport;
SvXMLAutoStylePoolP& rAutoStylePool;
diff --git a/include/xmloff/xmlcnimp.hxx b/include/xmloff/xmlcnimp.hxx
index 70825653f2b8..aefee1c7ecd4 100644
--- a/include/xmloff/xmlcnimp.hxx
+++ b/include/xmloff/xmlcnimp.hxx
@@ -22,14 +22,14 @@
#include <xmloff/dllapi.h>
#include <sal/types.h>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
class SvXMLAttrCollection;
class XMLOFF_DLLPUBLIC SvXMLAttrContainerData
{
private:
- boost::scoped_ptr<SvXMLAttrCollection> pimpl;
+ std::unique_ptr<SvXMLAttrCollection> pimpl;
public:
SvXMLAttrContainerData();
diff --git a/include/comphelper/scoped_disposing_ptr.hxx b/include/comphelper/scoped_disposing_ptr.hxx
index e1f7b20a5afb..2625f40510b9 100644
--- a/include/comphelper/scoped_disposing_ptr.hxx
+++ b/include/comphelper/scoped_disposing_ptr.hxx
@@ -12,7 +12,6 @@
#include <cppuhelper/implbase1.hxx>
#include <boost/utility.hpp>
-#include <boost/scoped_ptr.hpp>
#include <com/sun/star/lang/XComponent.hpp>
#include <com/sun/star/frame/XDesktop.hpp>
@@ -22,42 +21,42 @@
namespace comphelper
{
//Similar to boost::scoped_ptr, except additionally releases the ptr on XComponent::disposing and/or XTerminateListener::notifyTermination if supported
template<class T> class scoped_disposing_ptr : private boost::noncopyable
{
private:
- boost::scoped_ptr<T> m_aItem;
+ std::unique_ptr<T> m_xItem;
::com::sun::star::uno::Reference< ::com::sun::star::frame::XTerminateListener> m_xTerminateListener;
public:
scoped_disposing_ptr( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XComponent > &rComponent, T * p = 0 )
- : m_aItem(p)
+ : m_xItem(p)
{
m_xTerminateListener = new TerminateListener(rComponent, *this);
}
virtual void reset(T * p = 0)
{
- m_aItem.reset(p);
+ m_xItem.reset(p);
}
T & operator*() const
{
- return *m_aItem;
+ return *m_xItem;
}
T * get() const
{
- return m_aItem.get();
+ return m_xItem.get();
}
T * operator->() const
{
- return m_aItem.get();
+ return m_xItem.get();
}
operator bool () const
{
- return static_cast< bool >(m_aItem);
+ return static_cast< bool >(m_xItem);
}
virtual ~scoped_disposing_ptr()
@@ -22,42 +21,42 @@
namespace comphelper
{
-//Similar to boost::scoped_ptr, except additionally releases the ptr on XComponent::disposing and/or XTerminateListener::notifyTermination if supported
+//Similar to std::unique_ptr, except additionally releases the ptr on XComponent::disposing and/or XTerminateListener::notifyTermination if supported
template<class T> class scoped_disposing_ptr : private boost::noncopyable
{